@@ -1,12 +1,6 @@
 from pydantic import BaseModel, Field
-from typing import (
-    Annotated,
-    Generic,
-    Optional,
-    TypeVar,
-    Union,
-)
-from maleo.types.misc import StringOrStringEnumT
+from typing import Annotated, Generic, TypeVar
+from maleo.types.misc import StrOrStrEnumT
 
 
 class BoundingBox(BaseModel):
@@ -16,30 +10,26 @@ class BoundingBox(BaseModel):
     y_max: Annotated[float, Field(0.0, description="Y Max", ge=0.0)]
 
 
-OptionalBoundingBox = Optional[BoundingBox]
+OptionalBoundingBox = BoundingBox | None
 OptionalBoundingBoxT = TypeVar("OptionalBoundingBoxT", bound=OptionalBoundingBox)
 
 
-class Finding(BaseModel, Generic[StringOrStringEnumT, OptionalBoundingBoxT]):
+class Finding(BaseModel, Generic[StrOrStrEnumT, OptionalBoundingBoxT]):
     id: Annotated[int, Field(..., description="Finding's ID")]
-    name: Annotated[StringOrStringEnumT, Field(..., description="Finding's Name")]
+    name: Annotated[StrOrStrEnumT, Field(..., description="Finding's Name")]
     confidence: Annotated[float, Field(..., description="Confidence", ge=0.0, le=1.0)]
     box: Annotated[OptionalBoundingBoxT, Field(..., description="Bounding Box")]
 
 
-class FindingWithoutBox(
-    Finding[StringOrStringEnumT, None], Generic[StringOrStringEnumT]
-):
+class FindingWithoutBox(Finding[StrOrStrEnumT, None], Generic[StrOrStrEnumT]):
     box: Annotated[None, Field(None, description="Bounding Box")] = None
 
 
-class FindingWithBox(
-    Finding[StringOrStringEnumT, BoundingBox], Generic[StringOrStringEnumT]
-):
+class FindingWithBox(Finding[StrOrStrEnumT, BoundingBox], Generic[StrOrStrEnumT]):
     box: Annotated[BoundingBox, Field(..., description="Bounding Box")]
 
 
-AnyFinding = Union[FindingWithoutBox, FindingWithBox]
+AnyFinding = FindingWithoutBox | FindingWithBox
 AnyFindingT = TypeVar("AnyFindingT", bound=AnyFinding)
-OptionalAnyFinding = Optional[AnyFinding]
+OptionalAnyFinding = AnyFinding | None
 OptionalAnyFindingT = TypeVar("OptionalAnyFindingT", bound=OptionalAnyFinding)
