@@ -1,5 +1,5 @@
 from copy import deepcopy
-from typing import Callable, Dict
+from typing import Callable
 from uuid import UUID
 from maleo.schemas.resource import ResourceIdentifier
 from ..enums.record import IdentifierType
@@ -7,7 +7,7 @@ from ..types.record import IdentifierValueType
 from . import XRAY_RESOURCE
 
 
-IDENTIFIER_TYPE_VALUE_TYPE_MAP: Dict[
+IDENTIFIER_TYPE_VALUE_TYPE_MAP: dict[
     IdentifierType,
     Callable[..., IdentifierValueType],
 ] = {
