@@ -1,5 +1,5 @@
 from enum import StrEnum
-from maleo.types.string import ListOfStrings
+from maleo.types.string import ListOfStrs
 
 
 class IdentifierType(StrEnum):
@@ -7,5 +7,5 @@ class IdentifierType(StrEnum):
     UUID = "uuid"
 
     @classmethod
-    def choices(cls) -> ListOfStrings:
+    def choices(cls) -> ListOfStrs:
         return [e.value for e in cls]
