@@ -1,13 +1,11 @@
 from pydantic import BaseModel, Field
 from typing import Annotated, Generic
-from maleo.types.uuid import OptionalListOfUUIDsT
+from maleo.types.uuid import OptListOfUUIDsT
 from ..enums.inference import OptionalListOfInferenceTypesT
 
 
-class InferenceIds(BaseModel, Generic[OptionalListOfUUIDsT]):
-    inference_ids: Annotated[
-        OptionalListOfUUIDsT, Field(..., description="Inference's ids")
-    ]
+class InferenceIds(BaseModel, Generic[OptListOfUUIDsT]):
+    inference_ids: Annotated[OptListOfUUIDsT, Field(..., description="Inference's ids")]
 
 
 class InferenceTypes(BaseModel, Generic[OptionalListOfInferenceTypesT]):
