@@ -16,9 +16,9 @@ from maleo.schemas.parameter import (
     ReadSingleParameter as BaseReadSingleParameter,
     ReadPaginatedMultipleParameter,
 )
-from maleo.types.dict import StringToAnyDict
-from maleo.types.integer import OptionalListOfIntegers
-from maleo.types.uuid import OptionalListOfUUIDs
+from maleo.types.dict import StrToAnyDict
+from maleo.types.integer import OptListOfInts
+from maleo.types.uuid import OptListOfUUIDs
 from ..enums.record_inference import IdentifierType
 from ..mixins.record import RecordIds
 from ..mixins.inference import InferenceIds
@@ -27,19 +27,20 @@ from ..types.record_inference import IdentifierValueType
 
 class ReadMultipleParameter(
     ReadPaginatedMultipleParameter,
-    InferenceIds[OptionalListOfUUIDs],
-    RecordIds[OptionalListOfUUIDs],
-    UUIDUserIds[OptionalListOfUUIDs],
-    UUIDOrganizationIds[OptionalListOfUUIDs],
-    UUIDs[OptionalListOfUUIDs],
-    Ids[OptionalListOfIntegers],
+    InferenceIds[OptListOfUUIDs],
+    RecordIds[OptListOfUUIDs],
+    UUIDUserIds[OptListOfUUIDs],
+    UUIDOrganizationIds[OptListOfUUIDs],
+    UUIDs[OptListOfUUIDs],
+    Ids[OptListOfInts],
 ):
     @property
     def _query_param_fields(self) -> set[str]:
         return {
             "ids",
             "uuids",
-            "statuses" "organization_ids",
+            "statuses",
+            "organization_ids",
             "user_ids",
             "record_ids",
             "inference_ids",
@@ -49,7 +50,7 @@ class ReadMultipleParameter(
             "use_cache",
         }
 
-    def to_query_params(self) -> StringToAnyDict:
+    def to_query_params(self) -> StrToAnyDict:
         params = self.model_dump(
             mode="json", include=self._query_param_fields, exclude_none=True
         )
@@ -64,8 +65,8 @@ class ReadSingleParameter(BaseReadSingleParameter[IdentifierType, IdentifierValu
     @classmethod
     def new(
         cls,
-        identifier: Literal[IdentifierType.ID],
-        value: int,
+        identifier_type: Literal[IdentifierType.ID],
+        identifier_value: int,
         statuses: ListOfDataStatuses = list(FULL_DATA_STATUSES),
         use_cache: bool = True,
     ) -> "ReadSingleParameter": ...
@@ -73,27 +74,27 @@ class ReadSingleParameter(BaseReadSingleParameter[IdentifierType, IdentifierValu
     @classmethod
     def new(
         cls,
-        identifier: Literal[IdentifierType.UUID],
-        value: UUID,
+        identifier_type: Literal[IdentifierType.UUID],
+        identifier_value: UUID,
         statuses: ListOfDataStatuses = list(FULL_DATA_STATUSES),
         use_cache: bool = True,
     ) -> "ReadSingleParameter": ...
     @classmethod
     def new(
         cls,
-        identifier: IdentifierType,
-        value: IdentifierValueType,
+        identifier_type: IdentifierType,
+        identifier_value: IdentifierValueType,
         statuses: ListOfDataStatuses = list(FULL_DATA_STATUSES),
         use_cache: bool = True,
     ) -> "ReadSingleParameter":
         return cls(
-            identifier=identifier,
-            value=value,
+            identifier_type=identifier_type,
+            identifier_value=identifier_value,
             statuses=statuses,
             use_cache=use_cache,
         )
 
-    def to_query_params(self) -> StringToAnyDict:
+    def to_query_params(self) -> StrToAnyDict:
         return self.model_dump(
             mode="json", include={"statuses", "use_cache"}, exclude_none=True
         )
